A cluster template created by handwriter with 40 clusters. This
template was created from 100 handwriting samples from the CSAFE Handwriting
Database, the CVL Handwriting Database, and the IAM Handwriting Database.
Usage
templateK40
Arguments
Format
A list containing the contents of the cluster template.
cluster
A vector of cluster assignments
for each graph used to create the cluster template. The clusters are numbered sequentially 1, 2,...,40.
centers
The final cluster centers produced by the K-Means algorithm.
K
The number of clusters in the template (40).
n
The number of training graphs to used to create the template (32,708).
wcd
The within cluster
distances, the distance between each graph and the nearest cluster center, on the final iteration of the K-means algorithm.
Details
handwriter splits handwriting samples into component shapes called
graphs. The graphs are sorted into 40 clusters with a K-Means algorithm.